import * as _nuxt_schema from '@nuxt/schema';
import { SupabaseClientOptions } from '@supabase/supabase-js';

interface CookieOptions {
    // (Optional) The Cookie name prefix. Defaults to `sb` meaning the cookies will be `sb-access-token` and `sb-refresh-token`.
    name?: string;
    // (Optional) The cookie lifetime (expiration) in seconds. Set to 8 hours by default.
    lifetime?: number;
    // (Optional) The cookie domain this should run on. Leave it blank to restrict it to your domain.
    domain?: string;
    path?: string;
    // (Optional) SameSite configuration for the session cookie. Defaults to 'lax', but can be changed to 'strict' or 'none'. Set it to false if you want to disable the SameSite setting.
    sameSite?: string;
  }

interface ModuleOptions {
    /**
     * Supabase API URL
     * @default process.env.SUPABASE_URL
     * @example 'https://*.supabase.co'
     * @type string
     * @docs https://supabase.com/docs/reference/javascript/initializing#parameters
     */
    url: string;
    /**
     * Supabase Client API Key
     * @default process.env.SUPABASE_KEY
     * @example '123456789'
     * @type string
     * @docs https://supabase.com/docs/reference/javascript/initializing#parameters
     */
    key: string;
    /**
     * Supabase Service key
     * @default process.env.SUPABASE_SERVICE_KEY
     * @example '123456789'
     * @type string
     * @docs https://supabase.com/docs/reference/javascript/initializing#parameters
     */
    serviceKey: string;
    /**
     * Supabase Client options
     * @default {}
     * @type object
     * @docs https://supabase.com/docs/reference/javascript/initializing#parameters
     */
    client?: SupabaseClientOptions<String>;
    /**
     * Supabase Client options
     * @default {
        name: 'sb',
        lifetime: 60 * 60 * 8,
        domain: '',
        path: '/',
        sameSite: 'lax'
      }
     * @type object
     * @docs https://supabase.com/docs/reference/javascript/initializing#parameters
     */
    cookies?: CookieOptions;
}
declare const _default: _nuxt_schema.NuxtModule<ModuleOptions>;

export { ModuleOptions, _default as default };
